@@ -1,7 +1,6 @@
 package linux
 
 import (
-	"github.com/k0sproject/k0sctl/configurer"
 	"github.com/k0sproject/rig"
 	"github.com/k0sproject/rig/os/registry"
 )
@@ -17,9 +16,7 @@ func init() {
 			return os.ID == "opensuse" || os.ID == "opensuse-microos"
 		},
 		func() interface{} {
-			linuxType := &OpenSUSE{}
-			linuxType.PathFuncs = interface{}(linuxType).(configurer.PathFuncs)
-			return linuxType
+			return &OpenSUSE{}
 		},
 	)
 }
